@@ -139,11 +139,10 @@ pyfmtools_src=['src/colamd.c','src/lp_lib.c','src/lp_params.c','src/lp_simplex.c
 	'src/lp_crash.c','src/lp_mipbb.c','src/lp_report.c','src/lp_wlp.c','src/yacc_read.c','src/lp_Hash.c','src/lp_MPS.c','src/lp_scale.c','src/lusol.c',
 	'src/fmrandom.cpp','src/fuzzymeasurefit.cpp','src/wrapperpy.cpp','src/fuzzymeasurefit3.cpp','src/fuzzymeasuretools.cpp']
 
-ffibuilder.set_source("_pyfmtools",""" #include "wrapperpy.h" """,  
+ffibuilder.set_source("_pyfmtools",r""" #include "wrapperpy.h" """,  
     sources=pyfmtools_src,   
     libraries=['m'], 
     include_dirs=[PATH],
-    extra_compile_args=["-Wc++11-extensions"]
     )
     
 
