@@ -48,4 +48,30 @@ print( "Choquet integral of ",x, " is ",z)
 z = pyw.Sugeno( x, vb, env)
 print("Sugeno integral of ",x,  " is ",z)
 
+
+###
+# Test generated wrapper
+###
+
+x = [0.2,0.5,0.4]
+v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
+kint = 2
+r = pyw.ChoquetKinter( x, v, kint, env)
+print( "Choquet integral of: ", kint, x, v)
+print( "equals: ", r)
+
+v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
+r = pyw.Orness(v, env)
+print( "orness value of the Choquet integral wrt fuzzy measure v: ", v)
+print( "equals: ", r)
+
+
+kint = 2
+v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
+nm = [0.0] * env.m
+pnm = pyw.NonmodularityIndexKinteractive( v, nm, kint, env)
+print( "nonmodularity indices of k-interactive fuzzy measure v: ", kint, v)
+print( "equals: ", pnm)
+
+
 pyw.fm_free( env);
